@@ -68,7 +68,8 @@ def list_opts():
         ('discovery', ironic_inspector.conf.discovery.list_opts()),
         ('dnsmasq_pxe_filter',
          ironic_inspector.conf.dnsmasq_pxe_filter.list_opts()),
-        ('swift', ironic_inspector.conf.swift.list_opts()),
+        ('extra_hardware', ironic_inspector.conf.extra_hardware.list_opts()),
+        ('healthcheck', ironic_inspector.conf.healthcheck.list_opts()),
         ('ironic', ironic_inspector.conf.ironic.list_opts()),
         ('iptables', ironic_inspector.conf.iptables.list_opts()),
         ('port_physnet', ironic_inspector.conf.port_physnet.list_opts()),
@@ -76,4 +77,5 @@ def list_opts():
         ('pci_devices', ironic_inspector.conf.pci_devices.list_opts()),
         ('pxe_filter', ironic_inspector.conf.pxe_filter.list_opts()),
         ('service_catalog', ironic_inspector.conf.service_catalog.list_opts()),
+        ('swift', ironic_inspector.conf.swift.list_opts()),
     ]
