@@ -13,10 +13,10 @@
 
 import datetime
 import time
+from unittest import mock
 
 import fixtures
 import futurist
-import mock
 from oslo_concurrency import lockutils
 from oslo_config import fixture as config_fixture
 from oslo_log import log
@@ -80,7 +80,7 @@ class BaseTest(test_base.BaseTestCase):
                     return call[0][1]
             except IndexError:
                 pass
-            return call[0][0]
+            return call[0][2]
 
         actual = sum(map(_get_patch_param, mock_call.call_args_list), [])
         self.assertPatchEqual(actual, expected)
@@ -171,17 +171,23 @@ class NodeTest(InventoryTest):
     def setUp(self):
         super(NodeTest, self).setUp()
         self.uuid = uuidutils.generate_uuid()
+
         fake_node = {
             'driver': 'ipmi',
             'driver_info': {'ipmi_address': self.bmc_address},
             'properties': {'cpu_arch': 'i386', 'local_gb': 40},
-            'uuid': self.uuid,
+            'id': self.uuid,
             'power_state': 'power on',
             'provision_state': 'inspecting',
             'extra': {},
             'instance_uuid': None,
             'maintenance': False
         }
+        # TODO(rpittau) the correct value is id, not uuid, based on the
+        # openstacksdk schema. The code and the fake_node date are correct
+        # but all the tests still use uuid, so just making it equal to id
+        # until we find the courage to change it in all tests.
+        fake_node['uuid'] = fake_node['id']
         mock_to_dict = mock.Mock(return_value=fake_node)
 
         self.node = mock.Mock(**fake_node)
